==> jboss-eap-6.2.3-src.zip: jboss-eap-6.2-src/ejb3/src/main/java/org/jboss/as/ejb3/deployment/processors/annotation/ClusteredAnnotationInformationFactory.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.ejb3.deployment.processors.annotation;

import org.jboss.as.ee.metadata.ClassAnnotationInformationFactory;
import org.jboss.as.ejb3.component.session.ClusteringInfo;
import org.jboss.ejb3.annotation.Clustered;
import org.jboss.jandex.AnnotationInstance;

/**
 * @author Paul Ferraro
 */
public class ClusteredAnnotationInformationFactory extends ClassAnnotationInformationFactory<Clustered, ClusteringInfo> {

    protected ClusteredAnnotationInformationFactory() {
        super(Clustered.class, null);
    }

    @Override
    protected ClusteringInfo fromAnnotation(AnnotationInstance annotationInstance) {
        return new ClusteringInfo();
    }
}

==> jboss-eap-6.3.0-src.zip: jboss-eap-6.3-src/ejb3/src/main/java/org/jboss/as/ejb3/deployment/processors/annotation/ClusteredAnnotationInformationFactory.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.ejb3.deployment.processors.annotation;

import org.jboss.as.ee.metadata.ClassAnnotationInformationFactory;
import org.jboss.as.ejb3.component.session.ClusteringInfo;
import org.jboss.ejb3.annotation.Clustered;
import org.jboss.jandex.AnnotationInstance;

/**
 * @author Paul Ferraro
 */
public class ClusteredAnnotationInformationFactory extends ClassAnnotationInformationFactory<Clustered, ClusteringInfo> {

    protected ClusteredAnnotationInformationFactory() {
        super(Clustered.class, null);
    }

    @Override
    protected ClusteringInfo fromAnnotation(AnnotationInstance annotationInstance, boolean replacement) {
        return new ClusteringInfo();
    }
}
